from PyQt5.QtCore import Qt

ElementAlign = {
    'center': Qt.AlignCenter,
    'hcenter': Qt.AlignHCenter,
    'vcenter': Qt.AlignVCenter,
    'bottom': Qt.AlignBottom,
    'top': Qt.AlignTop,
    'right': Qt.AlignRight,
    'left': Qt.AlignLeft
}